Get score breaks from configuration
get_score_breaks.RdReturns the configured score breaks, falling back to the package
constants when apply_config() has not been called.
get_score_breaks.RdReturns the configured score breaks, falling back to the package
constants when apply_config() has not been called.