Validate uploaded input file
validate_upload_input.RdChecks that a data frame has the columns and types expected for the
pre-joined data + subjects + parameters input file.
validate_upload_input.RdChecks that a data frame has the columns and types expected for the
pre-joined data + subjects + parameters input file.