Validate uploaded queries file
validate_upload_queries.RdChecks that a data frame has the columns required for query overlay on plots and display in the queries table.
validate_upload_queries.RdChecks that a data frame has the columns required for query overlay on plots and display in the queries table.