Validate uploaded untransformed file
validate_upload_untransformed.RdChecks that a data frame has the join-key columns required to link untransformed data back to the input measures.
validate_upload_untransformed.RdChecks that a data frame has the join-key columns required to link untransformed data back to the input measures.