Aggregate uploaded results by removing timeseries_id
aggregate_results.RdDrops the timeseries_id column and collapses rows by taking the
maximum fdr_corrected_pvalue_logp per group of remaining columns.
This dramatically reduces the size of the results data frame for large
uploads where many timeseries map to the same parameter/site/feature.