Prepare wide score table for a single parameter
prepare_score_table.RdPivots per-feature site scores into a wide data frame with one row per site
and one column per feature, plus an aggregated max_score column.
Arguments
- ctas_results
List as returned by
ctas::process_a_study().- parameter_id
Character scalar, the parameter to filter on.