Reconstruct ctas data structures from flat upload files
reconstruct_from_upload.RdTakes the flat uploaded data frames and splits them back into the list
structures expected by prepare_measures().
reconstruct_from_upload.RdTakes the flat uploaded data frames and splits them back into the list
structures expected by prepare_measures().